# dist_prb_a

Version: 1.0 / Last updated: 2020-07-28

## Installation

Ensure you have Python 3 installed on your system.

Run this command in a terminal:
   pip install dist_proba

## Usage license

This package can be used as indicated in the MIT license associated with the package, see license.txt for more details.
